import { Message, Loading } from 'element-ui';
import qs from 'qs';

export default function ({ store, redirect, app: { $axios } }) {
  $axios.setHeader('X-Requested-With', 'XMLHttpRequest');

  // Request拦截器：设置Token
  $axios.onRequest((config) => {
    // TODO 使用Vuex存储Token，并做持久化处理
    // config.headers.common['X-Token'] = store.state.token
    if (!config.url.includes('user/modify-headimg')) {
      config.data = qs.stringify(config.data, {
        allowDots: true
      });
    }

    return config;
  });
  // Error拦截器：出现错误的时候被调用，根据状态码做对应判断并显示全局Message
  $axios.onError((error) => {
    let code;
    if (error.response && error.response.status) {
      code = parseInt(error.response && error.response.status);
    } else if (error.message && error.message.includes('connect ENETUNREACH')) {
      code = -1;
    } else {
      code = 500;
    }

    console.log('error:', error);
    if (process.server) {
      if (code === 401) {
        redirect('/');
      } else {
        redirect('/error?code=' + code);
      }
    } else if (code === 401) {
      if (Loading.service({})) {
        Loading.service({}).close();
      }
      Message.error('您暂未登录');
    }

    return error;
    // switch (code) {
    //     // 未登录
    // case 401:
    //     redirect('/login')
    //     break
    // default:
    //     break
    // }
    // 使用Element的Message模块显示异常信息
    // Message.error(error.response.data.message, 5)
  });
  // Response拦截器：对正常返回的数据进行处理
  $axios.onResponse((response) => {
    // console.log('onResponse', response.data);
    // return response.data
    return response;
  });

  $axios.genSSROptions = (req) => {
    const options = {};
    if (req.headers.cookie) {
      options.headers = { Cookie: req.headers.cookie + ';' };
    }
    return options;
  };
}
