import moment from 'moment';
import { Message, Loading } from 'element-ui';

export const state = () => ({
  info: null,
  loginDialogVisible: false,
  loading: true,

  loginInfo: {
    loading: true,
    qrCodeImage: '',
    expireTime: 0,
    qrcodeExpire: false,
    requestTime: 0,
    timer: 0
  }
});

export const mutations = {
  setLoginDialog(state, show) {
    state.loginDialogVisible = show;
  },
  setLoginInfo(state, info) {
    state.loginInfo = { ...state.loginInfo, ...info };
  },

  setUserInfo(state, info) {
    if (info === null) {
      state.info = null;
    } else {
      state.info = { ...state.info, ...info };
    }
  },

  setLoading(state, loading) {
    state.loading = loading;
  }
};

export const getters = {
  isLogin: (state) => state.info != null
};

export const actions = {
  async showLoginDialog({ commit, dispatch, state }, show) {
    console.log('showLoginDialog', show);

    commit('setLoginDialog', show);

    if (!show) {
      if (state.loginInfo.timer !== 0) {
        clearTimeout(state.loginInfo.timer);
        commit('setLoginInfo', { timer: 0 });
      }
      return;
    }

    const time = moment().unix();
    commit('setLoginInfo', {
      loading: true,
      requestTime: time,
      qrcodeExpire: false
    });

    const data = await this.$axios.$post('/auth-qrcode', { time });
    console.log('showLoginDialog:', data);

    if (data.success) {
      commit('setLoginInfo', {
        loading: false,
        qrCodeImage: data.detail.qrcodeImg,
        expireTime: new Date().getTime() / 1000 + data.detail.expire_seconds
      });
      dispatch('checkLogin');
    }
  },

  checkLogin({ commit, state, dispatch }) {
    if (!state.loginDialogVisible) {
      return;
    }

    const timer = setTimeout(() => {
      commit('setLoginInfo', { timer: 0 });
      if (new Date().getTime() / 1000 >= state.loginInfo.expireTime) {
        clearTimeout(state.loginInfo.timer);
        commit('setLoginInfo', { timer: 0, qrcodeExpire: true });
      } else {
        dispatch('doLogin');
      }
    }, 3000);

    commit('setLoginInfo', { timer });
  },

  async doLogin({ commit, state, dispatch }) {
    if (typeof _hmt !== 'undefined') {
      // eslint-disable-next-line no-undef
      _hmt.push([
        '_trackEvent',
        this.getters['device/getDeviceType'] === 'pc'
          ? 'PC-登录成功'
          : 'MOBILE-登录成功',
        'show',
        '登录成功'
      ]);
    }
    const data = await this.$axios.$post('/login', {
      time: state.loginInfo.requestTime
    });
    console.log('doLogin:', data);
    if (data.success) {
      commit('setUserInfo', data.detail);
      commit('setLoginDialog', false);
      Message({
        showClose: true,
        message: '登录成功',
        type: 'success'
      });
      window.location.reload();
    } else {
      dispatch('checkLogin');
    }
  },

  async loadUserInfo({ commit, state, dispatch }) {
    commit('setLoading', true);
    const data = await this.$axios.$get('/user/info');
    commit('setLoading', false);
    console.log('loadUserInfo:', data);
    if (data.success) {
      commit('setUserInfo', data.detail);
    }
  },

  async userLogout({ commit, state, dispatch }) {
    const loadingInstance1 = Loading.service({ fullscreen: true });
    const data = await this.$axios.$post('/logout');
    loadingInstance1.close();
    console.log('userLogout:', data);
    if (data.success) {
      commit('setUserInfo', null);
      Message({
        showClose: true,
        message: '退出成功',
        type: 'success'
      });
      window.location.replace('/');
    }
  }
};
